Learn R Programming

statgenQTLxT (version 1.0.3)

covUnstr: Compute unstructured covariance

Description

Compute unstructured covariance pairwise using covPairwise or using a single model using covUnstr.

Usage

covUnstr(Y, K, X = NULL, fixDiag = FALSE, VeDiag = FALSE)

covPW(Y, K, X = NULL, fixDiag = FALSE, corMat = FALSE, parallel = FALSE)

Value

A list of two matrices Vg and Ve containing genotypic and environmental variance components respectively.

Arguments

Y

An n x p matrix of observed phenotypes, on p traits or trials for n individuals. No missing values are allowed.

K

An n x n kinship matrix.

X

An n x c covariate matrix, c being the number of covariates and n being the number of genotypes.

fixDiag

Should the diagonal of the covariate matrix be fixed during calculations? -- NOT YET IMPLEMENTED

VeDiag

Should Ve be a diagonal matrix?

corMat

Should the output be a correlation matrix instead of a covariance matrix?

parallel

Should the computation of variance components be done in parallel?