Learn R Programming

statgenQTLxT (version 1.0.3)

exclMarkers: Select markers to be excluded from GWAS scan.

Description

Helper function for selecting markers to be excluded from GWAS scan. Markers are excluded if they are identical to any of the snpCovariates (including the snpCovariates themselves).

Usage

exclMarkers(snpCov, markers, allFreq, ref = NULL)

Value

A numerical vector of markers to be exluded from the GWAS scan.

Arguments

snpCov

A character vector of snpCovariates.

markers

A matrix with marker information.

allFreq

A numerical vector of allele frequencies of the markers in markers. This could be computed from markers as well but it is needed in the general algorithm so to not redo things unnecessarily it is not redone here.