Compute unstructured covariance pairwise using covPairwise or using a
single model using covUnstr.
covUnstr(Y, K, X = NULL, fixDiag = FALSE, VeDiag = FALSE)covPW(Y, K, X = NULL, fixDiag = FALSE, corMat = FALSE, parallel = FALSE)
A list of two matrices Vg and Ve containing genotypic
and environmental variance components respectively.
An n x p matrix of observed phenotypes, on p traits or trials for n individuals. No missing values are allowed.
An n x n kinship matrix.
An n x c covariate matrix, c being the number of covariates and n being the number of genotypes.
Should the diagonal of the covariate matrix be fixed during calculations? -- NOT YET IMPLEMENTED
Should Ve be a diagonal matrix?
Should the output be a correlation matrix instead of a covariance matrix?
Should the computation of variance components be done in parallel?