Helper function for selecting markers to be excluded from GWAS scan. Markers are excluded if they are identical to any of the snpCovariates (including the snpCovariates themselves).
exclMarkers(snpCov, markers, allFreq, ref = NULL)A numerical vector of markers to be exluded from the GWAS scan.
A character vector of snpCovariates.
A matrix with marker information.
A numerical vector of allele frequencies of the markers in
markers. This could be computed from markers as well but it is
needed in the general algorithm so to not redo things unnecessarily it is
not redone here.